==> com.liferay.commerce.api-26.0.0-sources.jar: com/liferay/commerce/constants/CommerceConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.commerce.constants;

/**
 * @author Andrea Di Giorgi
 * @author Alessio Antonio Rendina
 * @author Marco Leo
 */
public class CommerceConstants {

	public static final String RESOURCE_NAME_COMMERCE_ADDRESS =
		"com.liferay.commerce.address";

	public static final String RESOURCE_NAME_COMMERCE_AVAILABILITY =
		"com.liferay.commerce.availability";

	public static final String RESOURCE_NAME_COMMERCE_HEALTH =
		"com.liferay.commerce.health";

	public static final String RESOURCE_NAME_COMMERCE_ORDER_TYPE =
		"com.liferay.commerce.order.type";

	public static final String RESOURCE_NAME_COMMERCE_SHIPMENT =
		"com.liferay.commerce.shipment";

	public static final String RESOURCE_NAME_COMMERCE_SUBSCRIPTION =
		"com.liferay.commerce.subscription";

	public static final String SERVICE_NAME_COMMERCE_ORDER =
		"com.liferay.commerce.order";

	public static final String SERVICE_NAME_COMMERCE_ORDER_FIELDS =
		"com.liferay.commerce.order.fields";

	public static final String SERVICE_NAME_COMMERCE_PRICE =
		"com.liferay.commerce.price";

	public static final String SERVICE_NAME_COMMERCE_SHIPPING =
		"com.liferay.commerce.shipping";

	public static final String SERVICE_NAME_COMMERCE_TAX =
		"com.liferay.commerce.tax";

}

==> com.liferay.commerce.api-64.0.0-sources.jar: com/liferay/commerce/constants/CommerceConstants.java <==
/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2.1 of the License, or (at your option)
 * any later version.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 */

package com.liferay.commerce.constants;

/**
 * @author Andrea Di Giorgi
 * @author Alessio Antonio Rendina
 * @author Marco Leo
 */
public class CommerceConstants {

	public static final String RESOURCE_NAME_COMMERCE_ADDRESS =
		"com.liferay.commerce.address";

	public static final String RESOURCE_NAME_COMMERCE_AVAILABILITY =
		"com.liferay.commerce.availability";

	public static final String RESOURCE_NAME_COMMERCE_HEALTH =
		"com.liferay.commerce.health";

	public static final String RESOURCE_NAME_COMMERCE_ORDER_TYPE =
		"com.liferay.commerce.order.type";

	public static final String RESOURCE_NAME_COMMERCE_SHIPMENT =
		"com.liferay.commerce.shipment";

	public static final String RESOURCE_NAME_COMMERCE_SUBSCRIPTION =
		"com.liferay.commerce.subscription";

	public static final String SERVICE_NAME_COMMERCE_ORDER =
		"com.liferay.commerce.order";

	public static final String SERVICE_NAME_COMMERCE_ORDER_FIELDS =
		"com.liferay.commerce.order.fields";

	public static final String
		SERVICE_NAME_COMMERCE_ORDER_IMPORTER_DATE_FORMAT =
			"com.liferay.commerce.order.importer.date.format";

	public static final String SERVICE_NAME_COMMERCE_PRICE =
		"com.liferay.commerce.price";

	public static final String SERVICE_NAME_COMMERCE_SHIPPING =
		"com.liferay.commerce.shipping";

	public static final String SERVICE_NAME_COMMERCE_TAX =
		"com.liferay.commerce.tax";

}
